====================
unisos.marme Library
====================

.. contents::
   :depth: 3
..

MARME (Multi-Account Resident Mail Exchanger) Pkg is a library and a
collection of ICMs for maintaining multiple mail sending and host
resident mailboxes using offlineimap and notmuch.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180051

Example Usage
=============

::

   from  unisos import icm
